@@ -72,9 +72,7 @@
 			 (indent-sexp)))]
 	"---"
 	["%_Comment Out Region" comment-region :active (region-exists-p)]
-	["Unc%_omment Region" (comment-region (region-beginning)
-					      (region-end) '(4))
-	 :active (region-exists-p)]
+	["Unc%_omment Region" uncomment-region :active (region-exists-p)]
 	"---"
 	,@(if popup-p
 	    '(["%_Find Function"
@@ -269,6 +267,16 @@ All commands in `shared-lisp-mode-map' are inherited by this map.")
   ;; doesn't need them.
 )
 
+;; XEmacs: add docstrings to the hooks
+(defvar emacs-lisp-mode-hook nil
+  "Hook to run when entering emacs-lisp-mode.")
+
+(defvar lisp-mode-hook nil
+  "Hook to run when entering lisp-mode.")
+
+(defvar lisp-interaction-mode-hook nil
+  "Hook to run when entering lisp-interaction-mode.")
+
 (defun emacs-lisp-byte-compile ()
   "Byte compile the file containing the current buffer."
   (interactive)
@@ -420,8 +428,8 @@ if that value is non-nil."
 (defcustom eval-interactive-verbose t
   "*Non-nil means that interactive evaluation can print messages.
 The messages are printed when the expression is treated differently
-using `\\[eval-last-sexp]' and `\\[eval-defun]' than it than it would have been
-treated noninteractively.
+using `\\[eval-last-sexp]' and `\\[eval-defun]' than it would have
+been treated noninteractively.
 
 The printed messages are \"defvar treated as defconst\" and \"defcustom
  evaluation forced\".  See `eval-interactive' for more details."
