@@ -3,6 +3,7 @@
 ;; Copyright (C) 1995 Electrotechnical Laboratory, JAPAN.
 ;; Licensed to the Free Software Foundation.
 ;; Copyright (C) 1997 MORIOKA Tomohiko
+;; Copyright (C) 2002 Ben Wing.
 
 ;; Keywords: multilingual, Vietnamese
 
@@ -29,6 +30,43 @@
 
 ;;; Code:
 
+;; Vietnamese VISCII.  VISCII is 1-byte character set which contains
+;; more than 96 characters.  Since Emacs can't handle it as one
+;; character set, it is divided into two: lower case letters and upper
+;; case letters.
+(make-charset 'vietnamese-viscii-lower "VISCII1.1 lower-case"
+	      '(dimension
+		1
+		registry "VISCII1.1"
+		chars 96
+		columns 1
+		direction l2r
+		final ?1
+		graphic 1
+		short-name "VISCII lower"
+		long-name "VISCII lower-case"
+		))
+
+(make-charset 'vietnamese-viscii-upper "VISCII1.1 upper-case"
+	      '(dimension
+		1
+		registry "VISCII1.1"
+		chars 96
+		columns 1
+		direction l2r
+		final ?2
+		graphic 1
+		short-name "VISCII upper"
+		long-name "VISCII upper-case"
+		))
+
+(modify-syntax-entry 'vietnamese-viscii-lower "w")
+(modify-syntax-entry 'vietnamese-viscii-upper "w")
+
+(define-category ?v "Vietnamese character.")
+(modify-category-entry 'vietnamese-viscii-lower ?v)
+(modify-category-entry 'vietnamese-viscii-upper ?v)
+
 (eval-and-compile
 
 (defvar viet-viscii-decode-table
@@ -207,10 +245,10 @@ Both tables are indexed by the position code of Vietnamese characters.")
 
 (make-coding-system
  'viscii 'ccl
- "Coding-system used for VISCII 1.1."
+ "VISCII 1.1 (Vietnamese)"
  `(mnemonic "VISCII"
-   decode ,ccl-decode-viscii
-   encode ,ccl-encode-viscii))
+   decode ccl-decode-viscii
+   encode ccl-encode-viscii))
 
 ;; it is not correct, but XEmacs doesn't have `ccl' category...
 (coding-system-put 'viscii 'category 'iso-8-1)
@@ -227,10 +265,10 @@ Both tables are indexed by the position code of Vietnamese characters.")
 
 (make-coding-system
  'vscii 'ccl
- "Coding-system used for VSCII 1.1."
+ "VSCII 1.1 (Vietnamese)"
  `(mnemonic "VSCII"
-   decode ,ccl-decode-vscii
-   encode ,ccl-encode-vscii))
+   decode ccl-decode-vscii
+   encode ccl-encode-vscii))
 
 ;; (make-coding-system
 ;;  'vietnamese-vscii 4 ?v
@@ -243,7 +281,7 @@ Both tables are indexed by the position code of Vietnamese characters.")
 
 (make-coding-system
  'viqr 'no-conversion
- "Coding-system used for VIQR."
+ "VIQR (Vietnamese)"
  '(mnemonic "VIQR"
    eol-type lf
    post-read-conversion viqr-post-read-conversion
@@ -264,12 +302,12 @@ Both tables are indexed by the position code of Vietnamese characters.")
 
 ;; For VISCII users
 (set-charset-ccl-program 'vietnamese-viscii-lower
-			 ccl-encode-viscii-font)
+			 'ccl-encode-viscii-font)
 (set-charset-ccl-program 'vietnamese-viscii-upper
-			 ccl-encode-viscii-font)
+			 'ccl-encode-viscii-font)
 ;; For VSCII users
-(set-charset-ccl-program 'vietnamese-viscii-lower ccl-encode-vscii-font)
-(set-charset-ccl-program 'vietnamese-viscii-upper ccl-encode-vscii-font)
+(set-charset-ccl-program 'vietnamese-viscii-lower 'ccl-encode-vscii-font)
+(set-charset-ccl-program 'vietnamese-viscii-upper 'ccl-encode-vscii-font)
 
 ;; (setq font-ccl-encoder-alist
 ;;       (cons (cons "viscii" ccl-encode-viscii-font) font-ccl-encoder-alist))
@@ -277,14 +315,22 @@ Both tables are indexed by the position code of Vietnamese characters.")
 ;; (setq font-ccl-encoder-alist
 ;;       (cons (cons "vscii" ccl-encode-vscii-font) font-ccl-encoder-alist))
 
-;; (defvar viet-viscii-nonascii-translation-table
-;;   (make-translation-table-from-vector viet-viscii-decode-table)
-;;   "Value of `nonascii-translation-table' in Vietnamese language environment.")
+(defvar viet-viscii-to-external-code-table
+  (let ((table (make-char-table 'generic))
+	(i 0)
+	(len (length viet-viscii-decode-table)))
+    (while (< i len)
+      (let ((ch (aref viet-viscii-decode-table i)))
+	(if (characterp ch)
+	    (put-char-table ch i table)))
+      (incf i)))
+  "Table to convert from characters to their VISCII code.")
 
 (set-language-info-alist
  "Vietnamese" '((charset vietnamese-viscii-lower vietnamese-viscii-upper)
 		(coding-system viscii vscii viqr)
 		(coding-priority viscii)
+		(locale "vietnamese" "vi")
 		(input-method . "vietnamese-viqr")
 		(features viet-util)
 		(sample-text . "Vietnamese (Ti,1*(Bng Vi,1.(Bt)	Ch,1`(Bo b,1U(Bn")
