@@ -476,7 +476,11 @@ fill_char_table (Lisp_Char_Table *ct, Lisp_Object value)
       if (!EQ (ct->level1[i], Qnull_pointer) &&
 	  CHAR_TABLE_ENTRYP (ct->level1[i]) &&
 	  !OBJECT_DUMPED_P (ct->level1[1]))
+#ifdef MC_ALLOC
+	free_lrecord (ct->level1[i]);
+#else /* not MC_ALLOC */
 	free_lcrecord (ct->level1[i]);
+#endif /* not MC_ALLOC */
       ct->level1[i] = value;
     }
 #endif /* MULE */
@@ -542,15 +546,17 @@ once per character).
 When Mule support exists, the types of ranges that can be assigned
 values are
 
--- all characters
+-- all characters (represented by t)
 -- an entire charset
--- a single row in a two-octet charset
+-- a single row in a two-octet charset (represented by a vector of two
+   elements: a two-octet charset and a row number; the row must be an
+   integer, not a character)
 -- a single character
 
 When Mule support is not present, the types of ranges that can be
 assigned values are
 
--- all characters
+-- all characters (represented by t)
 -- a single character
 
 To create a char table, use `make-char-table'.
@@ -590,7 +596,11 @@ sorts of values.  The different char table types are
   Lisp_Object obj;
   enum char_table_type ty = symbol_to_char_table_type (type);
 
+#ifdef MC_ALLOC
+  ct = alloc_lrecord_type (Lisp_Char_Table, &lrecord_char_table);
+#else /* not MC_ALLOC */
   ct = alloc_lcrecord_type (Lisp_Char_Table, &lrecord_char_table);
+#endif /* not MC_ALLOC */
   ct->type = ty;
   obj = wrap_char_table (ct);
   if (ty == CHAR_TABLE_TYPE_SYNTAX)
@@ -623,7 +633,11 @@ make_char_table_entry (Lisp_Object initval)
 {
   int i;
   Lisp_Char_Table_Entry *cte =
+#ifdef MC_ALLOC
+    alloc_lrecord_type (Lisp_Char_Table_Entry, &lrecord_char_table_entry);
+#else /* not MC_ALLOC */
     alloc_lcrecord_type (Lisp_Char_Table_Entry, &lrecord_char_table_entry);
+#endif /* not MC_ALLOC */
 
   for (i = 0; i < 96; i++)
     cte->level2[i] = initval;
@@ -637,7 +651,11 @@ copy_char_table_entry (Lisp_Object entry)
   Lisp_Char_Table_Entry *cte = XCHAR_TABLE_ENTRY (entry);
   int i;
   Lisp_Char_Table_Entry *ctenew =
+#ifdef MC_ALLOC
+    alloc_lrecord_type (Lisp_Char_Table_Entry, &lrecord_char_table_entry);
+#else /* not MC_ALLOC */
     alloc_lcrecord_type (Lisp_Char_Table_Entry, &lrecord_char_table_entry);
+#endif /* not MC_ALLOC */
 
   for (i = 0; i < 96; i++)
     {
@@ -666,7 +684,11 @@ as CHAR-TABLE.  The values will not themselves be copied.
 
   CHECK_CHAR_TABLE (char_table);
   ct = XCHAR_TABLE (char_table);
+#ifdef MC_ALLOC
+  ctnew = alloc_lrecord_type (Lisp_Char_Table, &lrecord_char_table);
+#else /* not MC_ALLOC */
   ctnew = alloc_lcrecord_type (Lisp_Char_Table, &lrecord_char_table);
+#endif /* not MC_ALLOC */
   ctnew->type = ct->type;
   ctnew->parent = ct->parent;
   ctnew->default_ = ct->default_;
@@ -912,8 +934,11 @@ updating_mirror_get_range_char_table (struct chartab_range *range,
 #endif /* ERROR_CHECK_TYPES */
 
 DEFUN ("get-range-char-table", Fget_range_char_table, 2, 3, 0, /*
-Find value for a range in CHAR-TABLE.
+Find value for RANGE in CHAR-TABLE.
 If there is more than one value, return MULTI (defaults to nil).
+
+Valid values for RANGE are single characters, charsets, a row in a
+two-octet charset, and all characters.  See `put-char-table'.
 */
        (range, char_table, multi))
 {
@@ -1055,7 +1080,11 @@ put_char_table (Lisp_Object table, struct chartab_range *range,
 	  int lb = XCHARSET_LEADING_BYTE (range->charset) - MIN_LEADING_BYTE;
 	  if (CHAR_TABLE_ENTRYP (ct->level1[lb]) &&
 	      !OBJECT_DUMPED_P (ct->level1[lb]))
+#ifdef MC_ALLOC
+	    free_lrecord (ct->level1[lb]);
+#else /* not MC_ALLOC */
 	    free_lcrecord (ct->level1[lb]);
+#endif /* not MC_ALLOC */
 	  ct->level1[lb] = val;
 	}
       break;
@@ -1128,8 +1157,9 @@ one of the following:
 
 -- t (all characters are affected)
 -- A charset (only allowed when Mule support is present)
--- A vector of two elements: a two-octet charset and a row number
-   (only allowed when Mule support is present)
+-- A vector of two elements: a two-octet charset and a row number; the row
+   must be an integer, not a character (only allowed when Mule support is
+   present)
 -- A single character
 
 VALUE must be a value appropriate for the type of CHAR-TABLE.
@@ -1161,7 +1191,8 @@ one of the following:
    (only allowed when Mule support is present)
 -- A single character
 
-With the values removed, the default value will be returned.
+With all values removed, the default value will be returned by 
+`get-char-table' and `get-range-char-table'.
 */
        (range, char_table))
 {
@@ -1452,12 +1483,18 @@ slow_map_char_table_fun (struct chartab_range *range,
 }
 
 DEFUN ("map-char-table", Fmap_char_table, 2, 3, 0, /*
-Map FUNCTION over entries in CHAR-TABLE, calling it with two args,
-each key and value in the table.
+Map FUNCTION over CHAR-TABLE until it returns non-nil; return that value.
+FUNCTION is called with two arguments, each key and entry in the table.
 
-RANGE specifies a subrange to map over and is in the same format as
-the RANGE argument to `put-range-table'.  If omitted or t, it defaults to
+RANGE specifies a subrange to map over.  If omitted or t, it defaults to
 the entire table.
+
+Both RANGE and the keys passed to FUNCTION are in the same format as the
+RANGE argument to `put-char-table'.  N.B. This function does NOT map over
+all characters in RANGE, but over the subranges that have been assigned to.
+Thus this function is most suitable for searching a char-table, or for
+populating one char-table based on the contents of another.  The current
+implementation does not coalesce ranges all of whose values are the same.
 */
        (function, char_table, range))
 {
