@@ -239,7 +239,7 @@ parse_doprnt_spec (const Ibyte *format, Bytecount format_length)
 		case ' ': spec.space_flag  = 1; break;
 		case '#': spec.number_flag = 1; break;
 		case '0': spec.zero_flag   = 1; break;
-		default: abort ();
+		default: ABORT ();
 		}
 	      NEXT_ASCII_BYTE (ch);
 	    }
@@ -408,7 +408,7 @@ get_doprnt_args (printf_spec_dynarr *specs, va_list vargs)
       else if (strchr (bigfloat_converters, ch))
 	arg.obj = va_arg (vargs, Lisp_Object);
 #endif
-      else abort ();
+      else ABORT ();
 
       Dynarr_add (args, arg);
     }
@@ -948,7 +948,7 @@ emacs_vsprintf_malloc_lisp (const CIbyte *format_nonreloc,
 		format_reloc, nargs, largs);
   Lstream_flush (XLSTREAM (stream));
   len = Lstream_byte_count (XLSTREAM (stream));
-  retval = (Ibyte *) xmalloc (len + 1);
+  retval = xnew_ibytes (len + 1);
   memcpy (retval, resizing_buffer_stream_ptr (XLSTREAM (stream)), len);
   retval[len] = '\0';
   Lstream_delete (XLSTREAM (stream));
@@ -1032,7 +1032,7 @@ emacs_vsprintf_malloc (const CIbyte *format, va_list vargs,
 		   vargs);
   Lstream_flush (XLSTREAM (stream));
   len = Lstream_byte_count (XLSTREAM (stream));
-  retval = (Ibyte *) xmalloc (len + 1);
+  retval = xnew_ibytes (len + 1);
   memcpy (retval, resizing_buffer_stream_ptr (XLSTREAM (stream)), len);
   retval[len] = '\0';
   end_gc_forbidden (count);
