@@ -62,16 +62,6 @@ Boston, MA 02111-1307, USA.  */
 #undef KERNEL_FILE
 #define KERNEL_FILE "/unix"
 
-/* Define C_ALLOCA if this machine does not support a true alloca
-   and the one written in C should be used instead.
-   Define HAVE_ALLOCA to say that the system provides a properly
-   working alloca function and it should be used.
-   Define neither one if an assembler-language alloca
-   in the file alloca.s should be used.  */
-
-#define C_ALLOCA
-/* #define HAVE_ALLOCA */
-
 /* Define NO_REMAP if memory segmentation makes it not work well
    to change the boundary between the text section and data section
    when Emacs is dumped.  If you define this, the preloaded Lisp
@@ -123,10 +113,6 @@ Boston, MA 02111-1307, USA.  */
 #undef FIRST_PTY_LETTER
 #define FIRST_PTY_LETTER 'q'
 
-/* Define STACK_DIRECTION for alloca.c */
-
-#define STACK_DIRECTION -1
-
 /* By Tor Arntsen <tor@spacetec.no> for XEmacs. */
 #ifdef USE_GCC
 #define C_SWITCH_MACHINE "-D_BSD_TYPES -mcpu=r4000 -mips2"
