@@ -576,7 +576,7 @@ set_frame_menubar (struct frame *f, int deep_p, int first_time_p)
 
   data = compute_menubar_data (f, menubar, deep_p);
   if (!data || (!data->next && !data->contents))
-    abort ();
+    ABORT ();
 
   if (!FRAME_X_MENUBAR_ID (f))
     FRAME_X_MENUBAR_ID (f) = new_lwlib_id ();
@@ -1375,8 +1375,6 @@ reinit_vars_of_menubar_x (void)
 void
 vars_of_menubar_x (void)
 {
-  reinit_vars_of_menubar_x ();
-
 #if defined (LWLIB_MENUBARS_LUCID)
   Fprovide (intern ("lucid-menubars"));
 #elif defined (LWLIB_MENUBARS_MOTIF)
