@@ -173,9 +173,9 @@ static const struct memory_description charset_description[] = {
   { XD_LISP_OBJECT, offsetof (Lisp_Charset, reverse_direction_charset) },
   { XD_LISP_OBJECT, offsetof (Lisp_Charset, ccl_program) },
   { XD_UNION, offsetof (Lisp_Charset, to_unicode_table),
-    XD_INDIRECT (0, 0), { &to_unicode_description } },
+    XD_INDIRECT (0, 0), { &to_unicode_description }, XD_FLAG_NO_KKCC },
   { XD_UNION, offsetof (Lisp_Charset, from_unicode_table),
-    XD_INDIRECT (1, 0), { &from_unicode_description } },
+    XD_INDIRECT (1, 0), { &from_unicode_description }, XD_FLAG_NO_KKCC },
   { XD_END }
 };
 
@@ -197,7 +197,11 @@ make_charset (int id, Lisp_Object name, int rep_bytes,
 
   if (!overwrite)
     {
+#ifdef MC_ALLOC
+      cs = alloc_lrecord_type (Lisp_Charset, &lrecord_charset);
+#else /* not MC_ALLOC */
       cs = alloc_lcrecord_type (Lisp_Charset, &lrecord_charset);
+#endif /* not MC_ALLOC */
       obj = wrap_charset (cs);
 
       if (final)
@@ -880,7 +884,11 @@ compute_charset_usage (Lisp_Object charset, struct charset_stats *stats,
 {
   struct Lisp_Charset *c = XCHARSET (charset);
   xzero (*stats);
+#ifdef MC_ALLOC
+  stats->other   += mc_alloced_storage_size (sizeof (*c), ovstats);
+#else /* not MC_ALLOC */
   stats->other   += malloced_storage_size (c, sizeof (*c), ovstats);
+#endif /* not MC_ALLOC */
   stats->from_unicode += compute_from_unicode_table_size (charset, ovstats);
   stats->to_unicode += compute_to_unicode_table_size (charset, ovstats);
 }
