@@ -306,8 +306,17 @@ write_string_to_external_output_va (const CIbyte *fmt, va_list args,
    window under MS Windows); do external-format conversion and call GETTEXT
    on the format string.  Automatically flush when done.
 
-   This is safe even when not initialized or when dying -- we don't do
-   conversion in such cases. */
+   NOTE: CIbyte means "internal format" data.  This includes the "..."
+   arguments.  For numerical arguments, we have to assume that vsprintf
+   will be a good boy and format them as ASCII.  For Mule internal coding
+   (and UTF-8 internal coding, if/when we get it), it is safe to pass
+   string values in internal format to be formatted, because zero octets
+   only occur in the NUL character itself.  Similarly, it is safe to pass
+   pure ASCII literal strings for these functions.  *Everything else must
+   be converted, including all external data.*
+
+   This function is safe to use even when not initialized or when dying --
+   we don't do conversion in such cases. */
 
 void
 stderr_out (const CIbyte *fmt, ...)
@@ -1444,17 +1453,30 @@ static void
 default_object_printer (Lisp_Object obj, Lisp_Object printcharfun,
 			int UNUSED (escapeflag))
 {
+#ifdef MC_ALLOC
+  struct lrecord_header *header =
+    (struct lrecord_header *) XPNTR (obj);
+#else /* not MC_ALLOC */
   struct lcrecord_header *header =
     (struct lcrecord_header *) XPNTR (obj);
+#endif /* not MC_ALLOC */
 
   if (print_readably)
     printing_unreadable_object
       ("#<%s 0x%x>",
+#ifdef MC_ALLOC
+       LHEADER_IMPLEMENTATION (header)->name,
+#else /* not MC_ALLOC */
        LHEADER_IMPLEMENTATION (&header->lheader)->name,
+#endif /* not MC_ALLOC */
        header->uid);
 
   write_fmt_string (printcharfun, "#<%s 0x%x>",
+#ifdef MC_ALLOC
+		    LHEADER_IMPLEMENTATION (header)->name,
+#else /* not MC_ALLOC */
 		    LHEADER_IMPLEMENTATION (&header->lheader)->name,
+#endif /* not MC_ALLOC */
 		    header->uid);
 }
 
@@ -1676,6 +1698,7 @@ print_internal (Lisp_Object obj, Lisp_Object printcharfun, int escapeflag)
 	      }
 	  }
 
+#ifndef MC_ALLOC
 	if (lheader->type == lrecord_type_free)
 	  {
 	    printing_major_badness (printcharfun, "freed lrecord", 0,
@@ -1688,6 +1711,7 @@ print_internal (Lisp_Object obj, Lisp_Object printcharfun, int escapeflag)
 				    lheader, BADNESS_NO_TYPE);
 	    break;
 	  }
+#endif /* not MC_ALLOC */
 	else if ((int) (lheader->type) >= lrecord_type_count)
 	  {
 	    printing_major_badness (printcharfun, "illegal lrecord type",
@@ -2192,11 +2216,17 @@ debug_p4 (Lisp_Object obj)
 	debug_out ("<< bad object type=%d 0x%lx>>", header->type,
 		   (EMACS_INT) header);
       else
+#ifdef MC_ALLOC
+	debug_out ("#<%s 0x%lx>",
+		   LHEADER_IMPLEMENTATION (header)->name,
+		   (EMACS_INT) ((struct lrecord_header *) header)->uid);
+#else /* not MC_ALLOC */
 	debug_out ("#<%s 0x%lx>",
 		   LHEADER_IMPLEMENTATION (header)->name,
 		   LHEADER_IMPLEMENTATION (header)->basic_p ?
 		   (EMACS_INT) header :
 		   ((struct lcrecord_header *) header)->uid);
+#endif /* not MC_ALLOC */
     }
 
   inhibit_non_essential_conversion_operations = 0;
