@@ -61,7 +61,9 @@ typedef unsigned char *POINTER;
 #include "getpagesize.h"
 
 #include <string.h>
+#ifndef MC_ALLOC
 void refill_memory_reserve (void);
+#endif /* not MC_ALLOC */
 
 #else	/* Not emacs.  */
 
@@ -984,7 +986,9 @@ r_alloc_free (POINTER *ptr)
   *ptr = 0;
 
 #ifdef emacs
+#ifndef MC_ALLOC
   refill_memory_reserve ();
+#endif /* not MC_ALLOC */
 #endif
 }
 
