@@ -239,6 +239,7 @@ static int
 gtk_text_width (struct frame *UNUSED (f), struct face_cachel *cachel,
 		CONST Ichar *str, Charcount len)
 {
+  /* !!#### */
   int width_so_far = 0;
   unsigned char *text_storage = (unsigned char *) ALLOCA (2 * len);
   struct textual_run *runs = alloca_array (struct textual_run, len);
@@ -457,7 +458,7 @@ gtk_output_display_block (struct window *w, struct display_line *dl, int block,
 		    break;
 
 		  case IMAGE_POINTER:
-		    abort ();
+		    ABORT ();
 
 		  case IMAGE_WIDGET:
 		      if (EQ (XIMAGE_INSTANCE_WIDGET_TYPE (instance),
@@ -481,14 +482,14 @@ gtk_output_display_block (struct window *w, struct display_line *dl, int block,
 		    break;
 
 		  default:
-		    abort ();
+		    ABORT ();
 		  }
 
 	      xpos += rb->width;
 	      elt++;
 	    }
 	  else
-	    abort ();
+	    ABORT ();
 	}
     }
 
@@ -659,6 +660,7 @@ gtk_output_string (struct window *w, struct display_line *dl,
 		   int width, face_index findex, int cursor,
 		   int cursor_start, int cursor_width, int cursor_height)
 {
+  /* !!#### Needs review */
   /* General variables */
   struct frame *f = XFRAME (w->frame);
   struct device *d = XDEVICE (f->device);
