@@ -355,7 +355,7 @@ tty_output_display_block (struct window *w, struct display_line *dl, int block,
 		    case IMAGE_TEXT:
 		    case IMAGE_POINTER:
 		    default:
-		      abort ();
+		      ABORT ();
 		    }
 		  IMAGE_INSTANCE_OPTIMIZE_OUTPUT
 		    (XIMAGE_INSTANCE (instance)) = 0;
@@ -365,7 +365,7 @@ tty_output_display_block (struct window *w, struct display_line *dl, int block,
 	      elt++;
 	    }
 	  else
-	    abort ();
+	    ABORT ();
 	}
     }
 
@@ -1057,6 +1057,7 @@ tty_ring_bell (struct device *d, int volume, int UNUSED (pitch),
 int
 init_tty_for_redisplay (struct device *d, char *terminal_type)
 {
+  /* !!#### Mule-ize this */
   int status;
   char entry_buffer[2044];
   /* char temp_buffer[2044]; */
