@@ -244,6 +244,7 @@ static int
 x_text_width (struct frame *UNUSED (f), struct face_cachel *cachel,
 	      const Ichar *str, Charcount len)
 {
+  /* !!#### Needs review */
   int width_so_far = 0;
   unsigned char *text_storage = (unsigned char *) ALLOCA (2 * len);
   struct textual_run *runs = alloca_array (struct textual_run, len);
@@ -483,7 +484,7 @@ x_output_display_block (struct window *w, struct display_line *dl, int block,
 		    case IMAGE_TEXT:
 		    case IMAGE_POINTER:
 		    default:
-		      abort ();
+		      ABORT ();
 		    }
 		  IMAGE_INSTANCE_OPTIMIZE_OUTPUT
 		    (XIMAGE_INSTANCE (instance)) = 0;
@@ -493,7 +494,7 @@ x_output_display_block (struct window *w, struct display_line *dl, int block,
 	      elt++;
 	    }
 	  else
-	    abort ();
+	    ABORT ();
 	}
     }
 
