@@ -1,6 +1,6 @@
 /* Synched up with: FSF 19.31. */
 
-/* Definitions file for GNU Emacs running on Mips operating system.
+/* Definitions file for XEmacs running on Mips operating system.
    That system can emulate either BSD or Sys V, in either case with changes.
    If BSD is defined, we assume BSD is being emulated; otherwise, Sys V.  */
 
@@ -10,7 +10,6 @@
 #define C_SWITCH_SYSTEM "-systype bsd43"
 #define LD_SWITCH_SYSTEM "-systype bsd43"
 #undef LIBS_SYSTEM
-/* #define LIBS_SYSTEM "-lmld" */ /* mrb */
 #define LIBS_DEBUG
 #define START_FILES "pre-crt0.o /lib/crt1.o"
 #define LIB_STANDARD "-lc /usr/lib/crtn.o"
@@ -25,7 +24,6 @@
 #include "usg5-2-2.h"
 
 #undef LIBS_SYSTEM
-/* #define LIBS_SYSTEM "-lmld" */ /* mrb */
 #define LIBS_DEBUG
 #define START_FILES "pre-crt0.o /usr/lib/crt1.o"
 #define LIB_STANDARD "-lbsd -lc /usr/lib/crtn.o"
@@ -46,8 +44,6 @@
    so don't use it.  */
 #define BROKEN_SELECT
 
-#define HAVE_PTYS
-
 /* ??? */
 #define IRIS
 
