@@ -2,11 +2,11 @@
 emacs_is_beta=t
 emacs_major_version=21
 emacs_minor_version=5
-emacs_beta_version=21
-xemacs_codename="corn"
+emacs_beta_version=22
+xemacs_codename="cucumber"
 emacs_kit_version=
 infodock_major_version=4
 infodock_minor_version=0
 infodock_build_version=8
-xemacs_extra_name="(+CVS-20050527)"
+xemacs_extra_name="(+CVS-20050913)"
 xemacs_release_date="2005-02-18"
